@@ -23,7 +23,7 @@
 
 unitize_core <- function(
   test.files, store.ids, state, pre, post, history, interactive.mode,
-  force.update, auto.accept, mode
+  force.update, auto.accept, mode, use.diff
 ) {
   # - Validation / Setup -------------------------------------------------------
 
@@ -75,6 +75,8 @@ unitize_core <- function(
   if(!is.TF(interactive.mode))
     stop("Argument `interactive.mode` must be TRUE or FALSE")
   if(!is.TF(force.update)) stop("Argument `force.update` must be TRUE or FALSE")
+  if(!is.TF(use.diff))
+    stop("Argument `use.diff` must be TRUE or FALSE")
 
   # Validate state; note that due to legacy code we disassemble state into the
   # par.env and other components
@@ -148,7 +150,7 @@ unitize_core <- function(
 
   opts <- options()
   opts.untz <- opts[grep("^unitizer\\.", names(opts))]
-  validate_options(opts.untz, test.files)
+  opts.untz <- validate_options(opts.untz, test.files)
 
   # Initialize new tracking object; this will also record starting state and
   # store unitizer options; open question of how exposed we want to be to
@@ -449,7 +451,8 @@ unitize_core <- function(
         force.update=force.update,
         auto.accept=auto.accept,
         history=history,
-        global=global
+        global=global,
+        use.diff=use.diff
       ),
       unitizerInteractiveFail=function(e) interactive.fail <<- TRUE
     )
@@ -591,7 +594,8 @@ unitize_eval <- function(tests.parsed, unitizers, global) {
 # @param force.update whether to store unitizer
 
 unitize_browse <- function(
-  unitizers, mode, interactive.mode, force.update, auto.accept, history, global
+  unitizers, mode, interactive.mode, force.update, auto.accept, history, global,
+  use.diff
 ) {
   # - Prep ---------------------------------------------------------------------
 
@@ -625,7 +629,9 @@ unitize_browse <- function(
   untz.browsers <- mapply(
     browsePrep, as.list(unitizers), mode=mode,
     start.at.browser=(identical(mode, "review") | !to.review) & !force.update,
-    MoreArgs=list(hist.con=hist.obj$con, interactive=interactive.mode),
+    MoreArgs=list(
+      hist.con=hist.obj$con, interactive=interactive.mode, use.diff=use.diff
+    ),
     SIMPLIFY=FALSE
   )
   # Decide what to keep / override / etc.
@@ -832,7 +838,8 @@ unitize_browse <- function(
           # unreviewed unitizers
 
           browse.res <- browseUnitizer(
-            unitizers[[i]], untz.browsers[[i]], force.update=force.update
+            unitizers[[i]], untz.browsers[[i]], force.update=force.update,
+            use.diff=use.diff
           )
           summaries@updated[[i]] <- browse.res@updated
           unitizers[[i]] <- browse.res@unitizer
